library(magrittr)
library(dplyr)
library(ggplot2)
library(rgdal)
library(RColorBrewer)
library(ggmap)
library(data.table)

# load data
# Daily PM10 prediction - AQUA
mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.AQ_Daily_clean.2003_2015.PM10.rds")
summary(mod3best$bestpred)
range(mod3best$day)
mod3best <- filter(mod3best,day>="2005-01-01")
mod3best <- as.data.table(mod3best)
range(mod3best$day)

# Create mean for all time period -Daily PM10 prediction - AQUA
out3 <- mod3best %>% group_by(aodid) %>%
  summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM10=mean(bestpred, na.rm=TRUE))
out3<-as.data.frame(out3)
out3$PM <- "PM10 Daily AQUA"

# Hourly PM10 prediction - AQUA
mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.AQ_Hourly_clean.2005_2015.PM10.rds")
summary(mod3best$bestpred)
range(mod3best$day)

# Create mean for all time period -Hourly PM10 prediction - AQUA
out1 <- mod3best %>% group_by(aodid) %>%
  summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM10=mean(bestpred, na.rm=TRUE))
out1<-as.data.frame(out1)
out1$PM <- "PM10 Hourly AQUA"

# Hourly PM10 prediction - TERRA
# mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.AQ_Hourly_clean.2005_2015.PM10.rds")
# summary(mod3best$bestpred)
# range(mod3best$day)
# 
# # Create mean for all time period -Hourly PM10 prediction - TERRA
# out2 <- mod3best %>% group_by(aodid) %>%
#   summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM10=mean(bestpred, na.rm=TRUE))
# out2<-as.data.frame(out1)
# out2$PM <- "PM10 Hourly TERRA"

# Bind the prediction together
out <- rbind(out3,out1,out2)

# Daily PM25 prediction - AQUA
mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.AQ_Daily_clean.2003_2015.PM25.rds")
# summary(mod3best$bestpred)
# range(mod3best$day)
mod3best <- filter(mod3best,day>="2005-01-01")
mod3best <- as.data.table(mod3best)
range(mod3best$day)

# Create mean for all time period -Daily PM25 prediction - AQUA
out4 <- mod3best %>% group_by(aodid) %>%
  summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM25=mean(bestpred, na.rm=TRUE))
out4<-as.data.frame(out4)
out4$PM <- "PM2.5 Daily AQUA"

# Hourly PM25 prediction - AQUA
mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.AQ_Hourly_clean.2005_2015.PM25.rds")
summary(mod3best$bestpred)
range(mod3best$day)

# Create mean for all time period -Hourly PM25 prediction - AQUA
out5 <- mod3best %>% group_by(aodid) %>%
  summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM25=mean(bestpred, na.rm=TRUE))
out5<-as.data.frame(out5)
out5$PM <- "PM2.5 Hourly AQUA"

# Hourly PM25 prediction - TERRA
mod3best=readRDS("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/RDS_files/Best_pred/bestpred.no_GAM.TR_Hourly_clean.2005_2015.PM25.rds")
summary(mod3best$bestpred)
range(mod3best$day)

# Create mean for all time period -Hourly PM25 prediction - TERRA
out6 <- mod3best %>% group_by(aodid) %>%
  summarise(lon=mean(lon_aod, na.rm=TRUE), lat =mean(lat_aod, na.rm=TRUE), PM25=mean(bestpred, na.rm=TRUE))
out6<-as.data.frame(out6)
out6$PM <- "PM2.5 Hourly TERRA"

# Bind the prediction together
out <- rbind(out3,out1)

# Load shapefiles
setwd("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/Qgis/General/Main_cities")
cities=readOGR(dsn=".","Main_cities_lat_long")
cities_f <- as.data.frame(cities)
setnames(cities_f,"X...._.._1","Name")
cities_f$Names <- c("Jerusalem","Haifa","Beer-Sheva","Tel-Aviv")

# Load border polygon
border=readOGR(dsn="N:/Projects/P028.IL.Israel.MAIAC.PM.V2/work/Qgis/General/Project_border","Project_border")
border <- spTransform(border,proj4string(cities))
# Extract area from project boreder area
b <- bbox(border)
area <- get_map(location = b, zoom = 8, maptype = "satellite")
#convert the spatial object to table
border_f = fortify(border)

# Plot the PM10 map
myPalette <- colorRampPalette(rev(brewer.pal(11, "Spectral")))

ggmap(area) +
  geom_point(data=out,aes(x=lon, y=lat,fill=PM10), size=1.5, colour = NA, shape=21)+ 
  scale_fill_gradientn("PM10",colours = myPalette(100),na.value="black") +
  geom_path(data = border_f, aes(x = long, y = lat), color="black", size=0.75)+
  geom_point(data = cities_f,aes(x=coords.x1, y=coords.x2),col="black")+
  geom_label(data = cities_f,aes(x=coords.x1, y=coords.x2,label=Names),hjust=0, nudge_x = -0.25, nudge_y = 0.02, vjust=0, fontface = "bold",size=3.5)+
  scale_x_continuous(breaks = c(34.5, 35, 35.5)) +
  ggtitle("PM10 estimation")+
  coord_map(xlim = c(34, 36),ylim=c(30.85,33.4)) +
  theme_bw()+
  theme(
    legend.title=element_text(colour = 'black',face="bold"),
    strip.background= element_rect(fill="light blue"),
    strip.text = element_text(family = "Trebuchet MS",colour = 'black',face="bold",size=15),
    plot.title = element_text(family = "Trebuchet MS", color="blue", face="bold", size=20, hjust=0.5, vjust=0.5),
    axis.title = element_blank(),
    axis.text.y = element_text(angle = 90, hjust = 0.5)
    ) +
  facet_wrap(~PM, nrow = 1)

bggplot(data = cities_f,aes(x=coords.x1, y=coords.x2),col="black")+
  geom_text(aes(label=Name),hjust=0, vjust=0)

setwd("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/results/Maps")
ggsave("PM10_estimation.tiff",dpi=600)
?ggsave

out <- rbind(out4,out5,out6)
names(out6)
# Plot the PM2.5 map
myPalette <- colorRampPalette(rev(brewer.pal(11, "Spectral")))

ggmap(area) +
  geom_point(data=out,aes(x=lon, y=lat,fill=PM25), size=1.5, colour = NA, shape=21)+ 
  scale_fill_gradientn("PM25",colours = myPalette(100),na.value="black") +
  geom_path(data = border_f, aes(x = long, y = lat), color="black", size=0.75)+
  geom_point(data = cities_f,aes(x=coords.x1, y=coords.x2),col="black")+
  geom_label(data = cities_f,aes(x=coords.x1, y=coords.x2,label=Names),hjust=0, nudge_x = -0.25, nudge_y = 0.02, vjust=0, fontface = "bold",size=3.5)+
  scale_x_continuous(breaks = c(34.5, 35, 35.5)) +
  ggtitle("PM2.5 estimation")+
  coord_map(xlim = c(34, 36),ylim=c(30.85,33.4)) +
  theme_bw()+
  theme(
    legend.title=element_text(colour = 'black',face="bold"),
    strip.background= element_rect(fill="light blue"),
    strip.text = element_text(family = "Trebuchet MS",colour = 'black',face="bold",size=15),
    plot.title = element_text(family = "Trebuchet MS", color="blue", face="bold", size=20, hjust=0.5, vjust=0.5),
    axis.title = element_blank(),
    axis.text.y = element_text(angle = 90, hjust = 0.5)
  ) +
  facet_wrap(~PM, nrow = 1)

bggplot(data = cities_f,aes(x=coords.x1, y=coords.x2),col="black")+
  geom_text(aes(label=Name),hjust=0, vjust=0)

setwd("N:/Projects/P028.IL.Israel.MAIAC.PM.V2/results/Maps")
ggsave("PM25_estimation.tiff",dpi=600)
?ggsave
