library(magrittr)
library(leaflet)
library(sp)
library(rgdal)
library(rgeos)
library(raster)
library(parallel)
library(plyr)
library(velox)

# Load grid
setwd("/media/qnap/Data/Echo")

# Load AOI
aoi = readOGR("./AOI/", "NE_MIA_20kbuf")

# Load Grid
grid = readRDS("./NEMIA.grid.01022017/grid_pnt.rds") # point grid
grid_1km = readRDS("./NEMIA.grid.01022017/grid_square_1km.rds") # square grid

###############################################################################
# Land Cover

# Read Land Cover raster
lu = raster("./NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/nlcd_2011_landcover_2011_edition_2014_10_10.img")

# Reproject 'grid' and 'AOI' to CRS of raster
grid_proj = spTransform(grid, proj4string(lu))
grid_1km_proj = spTransform(grid_1km, proj4string(lu))
aoi = spTransform(aoi, proj4string(lu))

# Crop raster
lu = crop(lu, aoi, progress = "text")

# Extract land cover to 'grid'

# Forest
start = Sys.time()
r = calc(lu, function(x) x %in% c(41, 42, 43), filename = "r.tif", overwrite = TRUE) # Reclassify
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$forestProp_1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_forestProp_1km.rds")
gc()

# Another opotion for calculating land cover proportion - takes much more time
# Forest - filter

# start = Sys.time()
# r = lu %in% c(41, 42, 43) # Reclassify
# m = focalWeight(lu, d = 500, type = 'rectangle') # Create weights matrix
# m[] = 1
# forest = focal(r, m, fun = mean, na.rm = TRUE) # Focal filter - 'mean' of '1's and '0's in 1 km rectangular neighborhood
# grid$forestProp_1km = extract(forest, grid_proj) # Extract to points
# end = Sys.time()
# end - start # 2.461578 hours

# To check if 'forestProp_1km' has NA

# Developed all levels (hi, med, lo)
start = Sys.time()
r = calc(lu, function(x) x %in% c(22, 23, 24), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$DevAll_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_DevAll_P1km.rds")
rm(r)
gc()

# Developed high
start = Sys.time()
r = calc(lu, function(x) x %in% c(24), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$DevH_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory

grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_DevH_P1km.rds")
rm(r)
gc()

# Developed Medium
start = Sys.time()
r = calc(lu, function(x) x %in% c(23), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$DevM_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_DevM_P1km.rds")
rm(r)
gc()

# Developed Low
start = Sys.time()
r = calc(lu, function(x) x %in% c(22), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$DevL_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_DevL_P1km.rds")
rm(r)
gc()

# Developed OS
start = Sys.time()
r = calc(lu, function(x) x %in% c(21), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$DevOS_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_DevOS_P1km.rds")
rm(r)
gc()

# Open Water
start = Sys.time()
r = calc(lu, function(x) x %in% c(11), filename = "r.tif", overwrite = TRUE)# Reclassify and save the result to prevent temp files accumulation
vx = velox(r) # 'RasterLayer' to 'velox' object
f = function(x) mean(x, na.rm = TRUE)
x = vx$extract(sp = grid_1km_proj, fun = f) # 'Fast' extraction method
grid_1km$Water_P1km = x[, 1] # Add new column in 'grid_1km' layer
end = Sys.time()
end - start # Takes 28 min

# Save the result and clean memory
grid_1km_t=as.data.frame(grid_1km)
saveRDS(grid_1km_t, "/media/qnap/Data/Echo/NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/grid_1km_Water_P1km.rds")
gc()

# Save shapefile and explore the results in QGIS with the original Land Cover data

writeOGR(grid_1km, dsn="./NLCD_2011_05022017/nlcd_2011_landcover_2011_edition_2014_10_10/LC_Proprtion/layer",  layer= "grid_1km_LC", driver="ESRI Shapefile")



