library(magrittr)
library(rgdal)
library(sp)
library(rgeos)
library(raster)
library(mapview)
library(parallel)
library(ncdf4)
library(reshape2)

setwd("/media/qnap/Data/Echo/NEMIA.grid.01022017")

# Read AOI
aoi = readOGR("/media/qnap/Data/Echo/AOI/", "NE_MIA_20kbuf")

# Read 'grid' points (tested performance with polygons and points outperformed by >2000X)
# Since NARR grids are coarse resolution (32 km) we will use point extraction
grid = readRDS("/media/qnap/Data/Echo/NEMIA.grid.01022017/grid_pnt.rds")

# Subset
grid = grid[, c("aodid")]

setwd("/media/qnap/Data/Echo/NOAA.NARR.daily.09022017")

year = 2013

template = expand.grid(
  aodid = unique(grid$aodid),
  date = seq(as.Date(paste0(year, "-01-01")), as.Date(paste0(year, "-12-31")), 1), 
  stringsAsFactors = FALSE
)

files = list.files(pattern = paste0("\\.", year, "\\.nc"))

for(i in files) {
  
  # NCDF file location
  # i = "/media/qnap/Data/Echo/NOAA.NARR.daily.09022017/air.2m.2000.nc"
  
  
  # Connect to netCDF file
  nc = nc_open(i)
  
  # Get variable name
  var = names(nc$var)[4]
  print(var)
  
  # Read time data
  time = ncvar_get(nc, "time")
  origin = as.POSIXct("1800-1-1 00:00:0.0", tz = "GMT")
  diffs = as.difftime(time, format = "%H", units = "hours")
  time = origin + diffs
  
  # Read values data
  #use brick from raster pack.
  r = brick(i, varname = var)
  aoi_proj = spTransform(aoi, proj4string(r))
  r = crop(r, aoi_proj)
  
  # Interactive map check
  # mapview::mapview(r[[1]])
  
  # Extract to Points
  
  # Reprojecting the grid to the CRS of the raster
  grid = spTransform(grid, proj4string(r))
  
  # Extract NARR values to the grid
  dat = extract(r, grid)
  dat = as.data.frame(dat)
  names(dat) = time
  dat = cbind(grid@data, dat)
  
  # Melt
  dat = melt(
    dat, 
    id.vars = c("aodid"),
    variable.name = "date",
    value.name = gsub(paste0("\\.", year, "\\.nc"), "", i)
  )
  
  # To 'Date'
  dat$date = as.Date(dat$date)
  
  # Join with template
  template = dplyr::left_join(template, dat, by = c("aodid", "date"))
  
  gc()
  
}

# Save table
saveRDS(
  template,
  paste0("/media/qnap/Data/Echo/NOAA.NARR.daily.09022017/NARR_", year, ".rds")
)













