# Calculate the percent of each cell occupied by each land cover class
post_process_clc <- function(x, ncores) {

  # Load a dictionary of CLC classes
  clc_dict <- fread("1.work/land_cover/clc_legend.csv")[CLC_CODE < 600]
  code_key <- clc_dict$CLC_CODE %>%
              as.character %>%
              magrittr::set_names(clc_dict$GRID_CODE)

  # In parallel, calculate the percent of each grid cell occupied by each clc class
  x <- split_into_n(x, ncores) %>%
       mclapply(function(splt) {

         lapply(splt, function(clc_pixels) {

           counts <- table(clc_pixels)
           as.list(counts / sum(counts)) %>% as.data.table

         }) %>% rbindlist(fill = TRUE)

       }, mc.cores = ncores) %>% rbindlist(fill = TRUE)

  # Rename columns to CLC class codes and reorder
  code_key[names(x)] %>% setnames(x, .)
  names(x) %>% sort %>% setcolorder(x, .)

  # Return
  x

}
