# Create a table associating 200 m and 1 km grid cells


# Load packages, helper functions, and constants
source("init.R")

report("---")
report("Creating a table associating 200 m and 1 km grid cells")


# Skip if output exists
out_path <- "1.work/grids/grd_crossref.fst"
skip_if_exist(out_path)

# Load 1 km and 200 m grid points
report("Loading grids")
grd_1km <- readRDS("1.work/grids/grd_1km_pts.rds")
grd_200m <- readRDS("1.work/grids/grd_200m_pts.rds") %>%
            spTransform(proj4string(grd_1km))

# Find the index of the 1 km cell that contains each 200 m point
report("Matching 200 m grid points to closest 1 km grid point")
matches <- get.knnx(coordinates(grd_1km), coordinates(grd_200m), k = 1) %>%
           as.data.table %>%
           setnames(c("idx", "dist"))

# Confirm no 200 m grid point is > 2 km from a 1 km grid point
summary(matches$dist)
stopifnot(max(matches$dist) < 2000)

# Create the crossref table
crossref <- data.table(
              grd_200m_id = grd_200m$id,
              grd_1km_id = grd_1km$id[matches$idx]
            ) %>%
            setkeyv(c("grd_200m_id", "grd_1km_id"))

# Confirm all 200 m grid points were matched to a 1 km grid point
crossref[is.na(grd_1km_id), ]
stopifnot(nrow(crossref[is.na(grd_1km_id), ]) == 0)

# Save to disk
report("Saving lookup table")
write_fst(crossref, out_path, compress = 100)
glue("  -> {out_path}") %>% report

report("Done")
