# Determine the amount of RAM (in kB)
get_mem <- function() {

  # In an OAR job, accessible memory is total memory / total cores * allocated cores
  if (!is.na(Sys.getenv("OAR_NODEFILE", unset = NA))) {

    cores <- parallel::detectCores()
    alloc <- length(readLines(Sys.getenv("OAR_NODEFILE")))
    mem <- system2("awk", "'/MemTotal/ {print $2}' /proc/meminfo", stdout = TRUE)
    as.integer(mem) / cores * alloc

  }
  else if (Sys.info()["sysname"] == "Linux") {

    mem <- system2("awk", "'/MemTotal/ {print $2}' /proc/meminfo", stdout = TRUE)
    as.integer(mem)

  }
  else if (Sys.info()["sysname"] == "Windows") {

    mem <- system2("wmic", "OS get TotalVisibleMemorySize /Value", stdout = TRUE)
    mem <- mem[grepl("TotalVisibleMemorySize", mem)]
    mem <- sub("TotalVisibleMemorySize=", "", mem)
    as.integer(mem)

  }
  else {

    stop(paste("Don't know how to get memory on", Sys.info()["sysname"], collapse = " "))

  }

}
