# Plot each layer of a summary raster and return all plots as a list
plot_summary_raster <- function(smry, label = NULL, layers = c("min", "mean", "max", "sd", "N"),
                                trim = 0.001) {

  # Plot each layer and return as list
  sapply(layers, function(layer) {

    # Set the limits and breaks for the color scale
    if (layer == "N") {

      breaks <- seq.int(0, maxValue(smry$N), length.out = 90)

    } else {

      # Set limits at bottom and top [trim] percentile (default 0.1%)
      lims <- quantile(smry[[layer]], c(trim, 1 - trim))
      breaks <- seq(floor(lims[1]), ceiling(lims[2]), length.out = 90)

    }

    # Plot
    levelplot(smry[[layer]], main = paste(label, layer), at = breaks, margin = FALSE, xlab = NULL,
              ylab = NULL, par.settings = infernoTheme, scales = list(draw = FALSE))

  }, simplify = FALSE)

}
