library(magrittr)
library(raster)

# Convert a data table of gridded data to a raster based on a template
# The template should be a SpatialPointsDataFrame of points in a regular grid and must have an "id"
# attribute that will be used to join the data on the data table's key column
table_to_raster <- function(dat, template) {

  # Join the data to the template ID
  rast_data <- data.table(id = template$id)
  rast_data <- dat[rast_data, on = magrittr::set_names("id", key(dat))]

  # Replace the grid id with an index (raster layers must be numeric)
  setnames(rast_data, key(dat), "index")
  rast_data[, index := seq_along(index)]

  # Exclude any character-type data columns (rasters layers must be numeric)
  char_cols <- sapply(rast_data, class) %>% equals("character") %>% which
  if (length(char_cols) > 0) {

    msg <- names(char_cols) %>%
           paste(collapse = " ") %>%
           paste("Raster cannot contain strings; excluding [", ., "]")
    warning(msg)
    rast_data[, (char_cols) := NULL]

  }

  # Convert to a RasterStack
  rast <- as(template, "SpatialPoints") %>%
          SpatialPixelsDataFrame(points = ., data = rast_data) %>%
          stack

  # Return
  rast

}
