library(magrittr)
library(data.table)
library(fst)
library(glue)
library(e1071)
library(mlr)
library(mlrMBO)
library(parallelMap)
library(ggplot2)


# CONCLUSION: SVM is much, much, slower than RF or XGB and has worse performance


source("2.scripts/helpers/report.R")
source("2.scripts/helpers/get_ncores.R")

# Setup -----

ncores <- get_ncores()
threads_fst(ncores)


year <- 2015
tvar <- "tmax"

mod4 <- glue("1.work/joined/mod4_{year}.fst") %>%
        read_fst(as.data.table = TRUE) %>%
        .[, day := format(date, "%j") %>% as.integer]



target <- glue("res_{tvar}")
dat <- mod4[, c(target, "climate", "elev", "pop", "artificial", "vegetation", "bare", "water",
                "ndvi", "bt", glue("pred_{tvar}"), "x", "y", "day"), with = FALSE] %>%
       na.omit



# FIXME just July
report("DEBUG ONLY JULY")
dat <- dat[day %in% unique(mod4[month(date) == 7, day]), ]



task <- makeRegrTask(
          id = glue("{tvar}_{year}_svm"),
          data = as.data.frame(dat),
          target = target,
          coordinates = dat[, c("x", "y")]
        )


# FIXME SVM is ridiculously slow
report("DEBUG downsample 0.2")
task <- downsample(task, 0.2)


svm <- makePreprocWrapperCaret(
         learner = makeLearner(cl = "regr.svm"),
         method = c("center", "scale")
       )

tune_wrap <- makeTuneWrapper(
               learner = svm,
               resampling = makeResampleDesc("Subsample", split = 0.2, iters = 2),
               measures = list(rsq, rmse, mae, timetrain),
               par.set = makeParamSet(
                 makeNumericParam("gamma", 0.00005, 10),
                 makeNumericParam("cost", 1, 1000)
               ),
               control = makeTuneControlMBO(budget = 5),
               show.info = TRUE
             )

# parallelStartMulticore(32, level = "mlr.resample", show.info = FALSE)

cv <- resample(
        learner = tune_wrap,
        task = task,
        resampling = makeResampleDesc("CV", iters = 3),
        measures = list(rsq, rmse, mae, timetrain),
        extract = getTuneResult, # keep tuning results
        keep.pred = FALSE,       # don't keep predictions
        show.info = TRUE
      )

# parallelStop()

cv$tune.results.x <- getNestedTuneResultsX(cv)
cv$hped <- generateHyperParsEffectData(cv)

ggplot(cv$hped$data, aes(x = gamma, y = cost, fill = rsq.test.mean)) +
  geom_tile() +
  facet_wrap("nested_cv_run")

plotHyperParsEffect(cv$hped, x = "gamma", y = "cost", z = "rsq.test.mean", plot.type = "contour",
                    interpolate = "regr.ksvm")

plotHyperParsEffect(cv$hped, x = "gamma", y = "rsq.test.mean") + facet_wrap("cost")
plotHyperParsEffect(cv$hped, x = "cost", y = "rsq.test.mean") + facet_wrap("gamma")


cv$hped$partial <- TRUE
plotHyperParsEffect(cv$hped, x = "gamma", y = "rsq.test.mean", plot.type = "line",
                    partial.dep.learn = "regr.ranger")
plotHyperParsEffect(cv$hped, x = "cost", y = "rsq.test.mean", plot.type = "line",
                    partial.dep.learn = "regr.ranger")






rf <- makeLearner(
        cl = "regr.ranger",
        importance = "impurity",
        num.threads = 48,
        num.trees = 400
      )

tune_rf <- makeTuneWrapper(
             learner = rf,
             resampling = makeResampleDesc("Subsample", split = 0.2, iters = 2),
             measures = list(rsq, rmse, mae, timetrain),
             par.set = makeParamSet(
                         makeIntegerParam("mtry", 3, 12)
                       ),
             control = makeTuneControlMBO(budget = 6),
             show.info = TRUE
           )

cv_rf <- resample(
           learner = tune_rf,
           task = task,
           resampling = makeResampleDesc("CV", iters = 3),
           measures = list(rsq, rmse, mae, timetrain),
           extract = getTuneResult,
           keep.pred = FALSE,
           show.info = TRUE
         )


cv_rf$tune.results.x <- getNestedTuneResultsX(cv_rf)

