#
# Generate stage 3 predictions using stage 2 models (m2)
#

# Load packages, helper functions, and constants
source("init.R")

report("---")
report("Generating stage 3 predictions (m2, mod3)")


# FIXME needed as long as old models have not been updated to include actual formula
construct_m2_formula <- function(response, predictor) {
  list(
    fixed = paste(response, "~", predictor) %>% as.formula,           # response ~ predictor
    random = paste("~ 1 +", predictor, "| grd_1km_id") %>% as.formula # ~ 1 + predictor | grd_1km_id
  )
}


# Predict for all cell-days using m2 ------------------------------------------

# Iterate over years
# ~ 40 min / year
for (year in constants$model_years) {

  # Skip if predictions already exist
  pred_m2_path <- paste("mod3", year, "pred_m2.fst", sep = "_") %>%
                  file.path(constants$predictions_dir, .)
  if (file.exists(pred_m2_path) && !OVERWRITE) {
    next
  }

  # Load mod3 data including the m1 predictions
  # ~ 5 min, ~ 23 GB
  mod3_path <- paste("mod3", year, "pred_m1.fst", sep = "_") %>%
               file.path(constants$predictions_dir, .)
  paste(year, ": loading", basename(mod3_path)) %>% report
  threads_fst(ncores)
  mod3 <- read_fst(mod3_path, as.data.table = TRUE)
  rm(mod3_path)

  # # Split mod3 into groups
  # # ~ 1 minute, ~ 11 GB
  # n_splits <- round(ncores / 8)
  # paste(year, ": splitting mod3 into", n_splits, "groups") %>% report
  # idw_cols <- paste0("idw_", t_cols)
  # mod3[, split_idx := ceiling(1:nrow(mod3) / (nrow(mod3) / n_splits))]
  # splits <- mod3[, c("date", "grd_1km_id", "split_idx", idw_cols), with = FALSE] %>%
  #           split(by = "split_idx")
  # mod3[, split_idx := NULL]
  # rm(idw_cols)

  #
  # ~ 220 GB RAM required to predict
  #
  t_cols <- c("tmin", "tmean", "tmax")
  for (t_col in t_cols) {

    # Load the m2 model
    # ~ 2.5 min, ~ 4.5 GB
    m2_path <- paste0("m2_", t_col, "_", year, ".rds") %>% file.path(constants$models_dir, .)
    paste(year, t_col, ": loading", basename(m2_path)) %>% report
    m2 <- readRDS(m2_path)

    # HACK for old models, set the model's formula
    # This is necessary b/c nlme saves the exact call to `lme` (e.g. fixed = fml$fixed);
    # setting the formula allows us to use the model in an environment that does not
    # contain the `fml` object
    if (is(m2$call$fixed, "call")) {
      fml <- construct_m2_formula(t_col, paste0("idw_", t_col))
      m2$call$fixed <- fml$fixed
      m2$call$random <- fml$random
    }

    # Predict in parallel over splits
    # ~ 3 min for 16 splits, may use up to 380 GB of RAM?
    # paste(year, t_col, ": generating stage 3 predictions in parallel") %>% report
    # preds <- mclapply(splits, function(splt, m2, year, t_col) {

    #            predict(m2, newdata = splt)

    #          }, m2 = m2, year = year, t_col = t_col, mc.cores = ncores) %>%
    #          unlist(use.names = FALSE)

    # # Add the predictions to mod3
    # mod3[, pred_m2 := preds]
    # rm(m2, preds)
    paste(year, t_col, ": generating stage 3 predictions") %>% report
    mod3[, paste0("m2_", t_col) := predict(m2, newdata = mod3)]

    rm(m2)
    gc()

  }

  # rm(models, splits)
  # gc()

  #
  # 29 GB memory used
  #

  # Save mod3 with the m2 predictions
  # ~ 7 min, ~ 13 GB file
  paste(year, ": saving predictions") %>% report
  threads_fst(ncores)
  write_fst(mod3, pred_m2_path, compress = 100)
  paste(year, ": ->", basename(pred_m2_path)) %>% report

  # Cleanup
  paste(year, ": cleaning environment") %>% report
  rm(mod3)
  gc()

  #
  # 700 MB memory used
  #

}

rm(pred_m2_path, year, construct_m2_formula)

report(glue("Done {paste(range(constants$model_years), collapse = '-')}"))
