# Format corine land cover data
#
# For each land cover data year
# * Disaggregate to 50 m

source("init.R")

report("---")
report("Formatting Corine Land Cover data")


# Set the directory containing preprocessed corine land cover data
# The data was been mosaiced and clipped to France with a 1 km buffer in ArcGIS
clc_dir <- file.path(constants$work_dir, "land_cover")
dir.create(clc_dir, showWarnings = FALSE)

# For each land cover data year, load the data and disaggregate to 50 m
for (year in constants$clc_years) {

  # Skip if output exists unless OVERWRITE == TRUE
  out_path <- paste0("clc_", year, "_france_50m.tif") %>% file.path(clc_dir, .)
  if (file.exists(out_path) && !OVERWRITE) {
    next
  }

  paste("Loading CLC", year, "data") %>% report
  clc_data <- paste0("clc_", year, "_france.tif") %>% file.path(clc_dir, .) %>% raster

  # Disaggregate from 100 m to 50 m
  report("  Disaggregating to 50 m")
  clc_data <- disaggregate(clc_data, 2)

  # Save the disaggregated data
  paste("  Saving to", path) %>% report
  save_geotiff(clc_data, out_path, overwrite = TRUE)

  # Cleanup
  rm(clc_data)

}

# Cleanup
rm(clc_dir, year, out_path)

report("Done")
