# Check that the ELFE cohort participants are contained by the 200 m grid

# Load packages, helper functions, and constants
source("init.R")

# Load ELFE participant locations
pts <- fread(
         file = "0.raw/cohorts/mater_mere_geocod_v3.csv",
         col.names = c("id_dem220_110_jl", "x", "y", "qualitvoim"),
         data.table = FALSE
       ) %>%
       na.omit(cols = c("x", "y")) %>%
       st_as_sf(coords = c("x", "y"), crs = 27572)


# Check contained by 1 km grid cells
grd_1km <- raster("1.work/grids/grd_1km_pxs_sinu.tif")
pts$in_1km <- proj4string(grd_1km) %>%
                  st_transform(pts, .) %>%
                  raster::extract(grd_1km, .) %>%
                  is.na %>%
                  not
n_in_1km <- pts$in_1km %>% which %>% length
n_out_1km <- pts$in_1km %>% not %>% which %>% length

glue("In 1 km grid: {n_in_1km} ({round(n_in_1km / nrow(pts) * 100, 1)}%)")
glue("Not in 1 km grid: {n_out_1km} ({round(n_out_1km / nrow(pts) * 100, 1)}%)")


# Check contained by 200 m grid cells
grd_200m <- st_read("1.work/grids/grd_200m_pys.shp")
pts$in_200m <- st_crs(grd_200m) %>%
                   st_transform(pts, .) %>%
                   st_intersects(grd_200m) %>%
                   sapply(function(x) { length(x) > 0 })
n_in_200m <- pts$in_200m %>% which %>% length
n_out_200m <- pts$in_200m %>% not %>% which %>% length

glue("In 200 m grid: {n_in_200m} ({round(n_in_200m / nrow(pts) * 100, 1)}%)")
glue("Not in 200 m grid: {n_out_200m} ({round(n_out_200m / nrow(pts) * 100, 1)}%)")


# Save and create maps
dir.create("3.outcomes/visualizations/cohort_grid_overlap")
st_write(pts, "3.outcomes/visualizations/cohort_grid_overlap/elfe.shp")

mapview(pts, burst = "in_1km")
mapview(pts, burst = "in_200m")

map <- mapview(pts, burst = "in_200m")
mapshot(map, file.path(getwd(), "3.outcomes/visualizations/cohort_grid_overlap/test.html"))
