#
# Set up the workspace
#

# Load packagages and constants
library(magrittr)                 # %>% pipe-like operator
library(parallel)                 # parallel computation
library(fst)                      # fast serialization
library(foreign)                  # dbf file support
library(glue)                     # string interpolation
library(yaml)                     # YAML file support
library(lubridate)                # functions for working with dates
library(dplyr)                    # data manipulation e.g. joining tables
library(tidyr)                    # data tidying
library(purrr)                    # functional programming tools (e.g. map/reduce)
library(sp)                       # classes and methods for spatial data
library(rgdal)                    # wrapper for GDAL and proj.4 to translate spatial data
library(rgeos)                    # wrapper for GEOS to manipulate vector data
library(raster)                   # gridded spatial data
library(velox)                    # fast extraction from rasters
library(igraph)                   # raster zonal statistics
library(gdalUtils)                # extends rgdal and raster to manipulate HDF4 files
library(gstat)                    # IDW interpolation
library(sf)                       # modernized spatial data processing
library(nngeo)                    # geographic k nearest neighbours
library(FNN)                      # fast k nearest neighbours
library(Matrix)                   # required by lme4
library(nlme)                     # linear mixed models
library(lme4)                     # linear mixed models, load afte nlme b/c prefer lme4
library(LMERConvenienceFunctions) # automatic stepwise fitting for lme4
library(mgcv)                     # generalized additive models (for ensemble)
library(ranger)
library(xgboost)
library(mlr)
library(mlrMBO)
library(mmpf)       # needed to generate hperparam tuning plots
library(data.table) # fast data manipulation
# library(cowplot)    # aligning multiple plots
# library(plotly)     # interactive plots
library(ggplot2)    # plotting
library(mapview)    # interactive maps
library(rasterVis)  # plotting rasters

# Load helper functions
source("2.scripts/helpers/constants.R")
source("2.scripts/helpers/report.R")
source("2.scripts/helpers/assess_preds.R")
source("2.scripts/helpers/get_mem.R")
source("2.scripts/helpers/get_ncores.R")
source("2.scripts/helpers/geotiff_io.R")
source("2.scripts/helpers/parallel_velox_extract.R")
source("2.scripts/helpers/plot_summary_raster.R")
source("2.scripts/helpers/scale_cols.R")
source("2.scripts/helpers/shorten.R")
source("2.scripts/helpers/skip_if_exist.R")
source("2.scripts/helpers/source_or_skip.R")
source("2.scripts/helpers/split_into_n.R")
source("2.scripts/helpers/summarize_as_raster.R")
source("2.scripts/helpers/table_to_raster.R")

# Set the number of cores to use for parallel computation
ncores <- get_ncores()
threads_fst(ncores)
