#!/usr/bin/env bash

#OAR --project pr-edenpelagie
#OAR -l /nodes=1/core=12,walltime=02:00:00

set -e

# Activate conda environment
source ~/init-mamba.sh
micromamba activate r4.4.3

# Write predictions to netCDFs
Rscript pred1km2nc.R
Rscript pred200m2nc.R

# Return to current dir on exit
trap "cd \"${PWD}\"" EXIT

# Create annual tar archives of netCDFs
preds_dir="1.work/predictions"
cd "$preds_dir"
for year in $(seq 2000 2018);
do
  path_1km="ta_1km_${year}.tar"
  path_200m="ta_200m_${year}.tar"
  if [[ -f "$path_1km" && -f "$path_200m" ]]; then
    continue
  fi
  echo "Archiving ${year} netCDFs"
  if [[ ! -f $path_1km ]]; then
    tar -v --create --file "${path_1km}.tmp" "ta_1km_${year}*.nc"
    mv "${path_1km}.tmp" "$path_1km"
    echo "-> ${preds_dir}/${path_1km}"
  fi
  if [[ ! -f $path_200m ]]; then
    tar -v --create --file "${path_200m}.tmp" "ta_200m_${year}*.nc"
    mv "${path_200m}.tmp" "$path_200m"
    echo "-> ${preds_dir}/${path_200m}"
  fi
done
